# Cronaion
Watcher

* A scheduler for your python programs
* Easily schedule with a cronjob string
* Very light on cpu as there are just sleeps called, not a while loop checker.
* Everything is run as a thread
